function [H] = Hensemble_estimation(Y,co)
%Estimates entropy (H) from the average of entropy estimations on groups of samples; this a "meta" method, the applied entropy estimator can be arbitrary.
%
%We make use of the naming convention 'H<name>_estimation', to ease embedding new entropy estimation methods.
%
%INPUT:
%   Y: Y(:,t) is the t^th sample.
%  co: entropy estimator object.
%REFERENCE: 
%  Jan Kybic: High-dimensional mutual information estimation for image registration. ICIP 2004, pages 17791782.
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%initialization:
    g = co.group_size;    
    num_of_samples = size(Y,2);
    num_of_groups = floor(num_of_samples/g);
    
H = 0;    
for k = 1 : num_of_groups
    H = H + H_estimation(Y(:,(k-1)*g+1:k*g),co.member_co);
end
H = H / num_of_groups;
