function [I_alpha]  = IRenyi_HRenyi_estimation(Y,ds,co)
%Estimates Renyi mutual information using the formula: "I_{alpha}(Y) = -H_{alpha}(Z)", where Z =[F_1(Y_1);...;F_d(Y_d)] is the copula transformation of Y; F_i is the cdf of Y_i.
%This is a "meta" method, i.e., the H_{alpha} estimator can be arbitrary.
%
%We make use of the naming convention 'I<name>_estimation', to ease embedding new mutual information estimation methods.
%
%INPUT:
%   Y: Y(:,t) is the t^th sample.
%  ds: subspace dimensions.
%  co: mutual information estimator object.
%REFERENCE:
%   David Pal, Barnabas Poczos, Csaba Szepesvari: Estimation of Renyi Entropy and Mutual Information Based on
%   Generalized Nearest-Neighbor Graphs. NIPS-2010 pages 1849-1857.
%   Barnabas Poczos, Sergey Krishner, Csaba Szepesvari. REGO: Rank-based Estimation of Renyi Information using Euclidean Graph
%   Optimization. AISTATS-2010, pages 605-612.
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

if one_dimensional_problem(ds)
    Z = copula_transformation(Y);
    I_alpha = -H_estimation(Z,co.member_co);
else
    disp('Error: the subspaces must be one-dimensional for this estimator.');
end
